@@ -1,8 +1,9 @@
 import json
 import decimal
 from contracting.stdlib.bridge.time import Datetime, Timedelta
-from contracting.stdlib.bridge.decimal import ContractingDecimal
+from contracting.stdlib.bridge.decimal import ContractingDecimal, MAX_LOWER_PRECISION, fix_precision
 from contracting.config import INDEX_SEPARATOR, DELIMITER
+
 ##
 # ENCODER CLASS
 # Add to this to encode Python types for storage.
@@ -10,7 +11,6 @@ from contracting.config import INDEX_SEPARATOR, DELIMITER
 # and stored as dicts. Is there a better way? I don't know, maybe.
 ##
 
-
 def safe_repr(obj, max_len=1024):
     r = obj.__repr__()
     rr = r.split(' at 0x')
@@ -34,10 +34,22 @@ class Encoder(json.JSONEncoder):
                 '__bytes__': o.hex()
             }
         elif isinstance(o, decimal.Decimal) or o.__class__.__name__ == decimal.Decimal.__name__:
-            return float(o)
+            #return format(o, f'.{MAX_LOWER_PRECISION}f')
+            return {
+                '__fixed__': str(fix_precision(o))
+            }
 
         elif isinstance(o, ContractingDecimal) or o.__class__.__name__ == ContractingDecimal.__name__:
-            return float(o._d)
+            #return format(o._d, f'.{MAX_LOWER_PRECISION}f')
+            return {
+                '__fixed__': str(fix_precision(o._d))
+            }
+        elif isinstance(o, float):
+            #return format(o, f'.{MAX_LOWER_PRECISION}f')
+            _o = format(o, f'.{MAX_LOWER_PRECISION}f')
+            return {
+                '__fixed__': str(fix_precision(decimal.Decimal(_o)))
+            }
         #else:
         #    return safe_repr(o)
 
@@ -56,6 +68,8 @@ def as_object(d):
         return Timedelta(days=d['__delta__'][0], seconds=d['__delta__'][1])
     elif '__bytes__' in d:
         return bytes.fromhex(d['__bytes__'])
+    elif '__fixed__' in d:
+        return ContractingDecimal(d['__fixed__'])
     return dict(d)
 
 
