@@ -2,10 +2,10 @@ import importlib
 from contracting.execution import runtime
 from contracting.db.driver import ContractDriver
 from contracting.execution.module import install_database_loader, uninstall_builtins, enable_restricted_imports, disable_restricted_imports
-from contracting.stdlib.bridge.decimal import ContractingDecimal
+from contracting.stdlib.bridge.decimal import ContractingDecimal, CONTEXT
 from contracting import config
 from copy import deepcopy
-
+import decimal
 from logging import getLogger
 
 log = getLogger('CONTRACTING')
@@ -76,7 +76,7 @@ class Executor:
 
             runtime.rt.env.update(environment)
             status_code = 0
-            runtime.rt.set_up(stmps=stamps, meter=metering)
+            runtime.rt.set_up(stmps=stamps * 1000, meter=metering) # Multiply stamps by 1000 because we divide by it later
 
             runtime.rt.context._base_state = {
                 'signer': sender,
@@ -88,9 +88,15 @@ class Executor:
             if runtime.rt.context.owner is not None and runtime.rt.context.owner != runtime.rt.context.caller:
                 raise Exception(f'Caller {runtime.rt.context.caller} is not the owner {runtime.rt.context.owner}!')
 
+            decimal.setcontext(CONTEXT)
+
             module = importlib.import_module(contract_name)
             func = getattr(module, function_name)
 
+            for k, v in kwargs.items():
+                if type(v) == float:
+                    kwargs[k] = ContractingDecimal(str(v))
+
             enable_restricted_imports()
             result = func(**kwargs)
             disable_restricted_imports()
@@ -117,6 +123,9 @@ class Executor:
         stamps_used += 1
         #stamps_used *= 1000
 
+        if stamps_used > stamps:
+            stamps_used = stamps
+
         if metering:
             assert balances_key is not None, 'Balance key was not set properly. Cannot deduct stamps.'
 
@@ -145,6 +154,7 @@ class Executor:
             'result': result,
             'stamps_used': stamps_used,
             'writes': deepcopy(driver.pending_writes),
+            'reads': driver.reads
         }
 
         disable_restricted_imports()
