@@ -3,7 +3,7 @@ import erc20_clone
 swaps = Hash()
 
 @export
-def initiate(participant: str, expiration: datetime, hashlock: str, amount: float):
+def initiate(participant: str, expiration: datetime.datetime, hashlock: str, amount: float):
     allowance = erc20_clone.allowance(ctx.caller, ctx.this)
 
     assert allowance >= amount, \
