@@ -1,5 +1,8 @@
 from unittest import TestCase
 from contracting.execution import runtime
+import sys
+import psutil
+import os
 
 
 class TestRuntime(TestCase):
@@ -107,4 +110,4 @@ class TestRuntime(TestCase):
         used_1 = runtime.rt.tracer.get_stamp_used()
 
         runtime.rt.clean_up()
-        print(used_1)
\ No newline at end of file
+        print(used_1)
